@@ -3,9 +3,8 @@ from . import Data
 from . import Management
 from . import statistics
 from . import fileio
-from . import handle_contents
-from . import coordinate_generator
-from . import access
-from . import folder_to_lib
 from . import platform_specific
 from . import featurerecognition
+from . import pipes
+from . import coordinates
+from . import utilities
